==> JazaeriMetaData.db_2.2.0.tar.gz: JazaeriMetaData.db/man/JazaeriMetaData_dbconn.Rd <==
\name{JazaeriMetaData_dbconn}

\alias{JazaeriMetaData_dbconn}
\alias{JazaeriMetaData_dbfile}
\alias{JazaeriMetaData_dbschema}
\alias{JazaeriMetaData_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  JazaeriMetaData_dbconn()
  JazaeriMetaData_dbfile()
  JazaeriMetaData_dbschema(file="", show.indices=FALSE)
  JazaeriMetaData_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{JazaeriMetaData_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{JazaeriMetaData_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{JazaeriMetaData_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{JazaeriMetaData_dbschema} prints the schema definition of the
  package annotation DB.

  \code{JazaeriMetaData_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{JazaeriMetaData_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{JazaeriMetaData_dbfile}: a character string with the path to the
  package annotation DB.

  \code{JazaeriMetaData_dbschema}: none (invisible \code{NULL}).

  \code{JazaeriMetaData_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(JazaeriMetaData_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by JazaeriMetaData_dbconn() was created with:
  dbConnect(SQLite(), dbname=JazaeriMetaData_dbfile(), cache_size=64000, synchronous=0)

  JazaeriMetaData_dbschema()

  JazaeriMetaData_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> JazaeriMetaData.db_2.8.0.tar.gz: JazaeriMetaData.db/man/JazaeriMetaData_dbconn.Rd <==

\name{JazaeriMetaData_dbconn}

\alias{JazaeriMetaData_dbconn}
\alias{JazaeriMetaData_dbfile}
\alias{JazaeriMetaData_dbschema}
\alias{JazaeriMetaData_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  JazaeriMetaData_dbconn()
  JazaeriMetaData_dbfile()
  JazaeriMetaData_dbschema(file="", show.indices=FALSE)
  JazaeriMetaData_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{JazaeriMetaData_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{JazaeriMetaData_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{JazaeriMetaData_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{JazaeriMetaData_dbschema} prints the schema definition of the
  package annotation DB.

  \code{JazaeriMetaData_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{JazaeriMetaData_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{JazaeriMetaData_dbfile}: a character string with the path to the
  package annotation DB.

  \code{JazaeriMetaData_dbschema}: none (invisible \code{NULL}).

  \code{JazaeriMetaData_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(JazaeriMetaData_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by JazaeriMetaData_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=JazaeriMetaData_dbfile(), cache_size=64000,
  synchronous=0)

  JazaeriMetaData_dbschema()

  JazaeriMetaData_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
